<!---
The contents of this file are subject to the Mozilla Public License Version 1.1
(the "License"); you may not use this file except in compliance with the
License. You may obtain a copy of the License at http://www.mozilla.org/MPL/
 
Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
the specific language governing rights and limitations under the License.
 
The Original Code is comprised of the PT Sync directory
 
The Initial Developer of the Original Code is
PaperThin, Inc. Copyright(C) 2011.
All Rights Reserved.
 
By downloading, modifying, distributing, using and/or accessing any files
in this directory, you agree to the terms and conditions of the applicable
end user license agreement.
--->

<!---
/* *************************************************************** */
Author: 	
	PaperThin Inc.
	M. Carroll
Name:
	multi_server_site_select_render.cfm
Summary:
	CFT to render a select field of the CommonSpot sites on the server.
	Stores the Site ID.
	If the Sync App has Multi Server feature enabled, then the select field
		will build from the ptSync.xml config XML file.
		See Documentation for more details: 
		http://community.paperthin.com/adf-docs/index.php/PT_Sync_Multi_Server_Configuration
Version:
	1.1
History:
	2011-10-06 - MFC - Created
	2011-11-07 - MFC - Updated to check for Multi Server query has record count.
--->
<cfscript>
	// the fields current value
	currentValue = attributes.currentValues[fqFieldName];
	// the param structure which will hold all of the fields from the props dialog
	xparams = parameters[fieldQuery.inputID];

	//--Field Security--
	readOnly = application.ADF.forms.isFieldReadOnly(xparams);
	
	// Validate if the property field has been defined
	if ( NOT StructKeyExists(xparams, "fldID") OR LEN(xparams.fldID) LTE 0 )
		xparams.fldID = fqFieldName;
	
	// Check if the Multi Server is ENABLED
	if ( application.ptSync.appConfig.multiserver EQ TRUE ){
		// Get the Multi Server config query from cache
		multiServerQry = application.ptSync.cache.multiServer;
	}
	else {
		// Get all the CS Site Query for the site
		csSiteQry = application.ptSync.csData.getCommonSpotSites();
	}
</cfscript>
<cfoutput>
	<script>
		// javascript validation to make sure they have text to be converted
		#fqFieldName#=new Object();
		#fqFieldName#.id='#fqFieldName#';
		#fqFieldName#.tid=#rendertabindex#;
		#fqFieldName#.msg="Please select a value for the #xparams.label# field.";
		#fqFieldName#.validator = "validate_#fqFieldName#()";

		//If the field is required
		if ( '#xparams.req#' == 'Yes' ){
			// push on to validation array
			vobjects_#attributes.formname#.push(#fqFieldName#);
		}

		//Validation function
		function validate_#fqFieldName#(){
			if (jQuery("input[name=#fqFieldName#]").val() != ''){
				return true;
			}else{
				return false;
			}
		}
	</script>
<!---
	This version is using the wrapFieldHTML functionality, what this does is it takes
	the HTML that you want to put into the TD of the right section of the display, you
	can optionally disable this by adding the includeLabel = false (fourth parameter)
	when false it simply creates a TD and puts your content inside it. This wrapper handles
	everything from description to simple form field handling.
--->
	<cfsavecontent variable="inputHTML">
		<cfoutput>
			<select name="#fqFieldName#" id='#xparams.fldID#' <cfif readOnly>disabled="disabled"</cfif>>
				<option value=""> - Select -
				<!--- Check if the Multi Server is ENABLED and we have data in the query --->
				<cfif application.ptSync.appConfig.multiserver AND multiServerQry.recordCount>
					<cfset currServer = "">
					<cfloop query="multiServerQry">
						<!--- Display a set of the servers and sites --->
						<cfif server NEQ currServer>
							<cfset currServer = server>
							<!--- Display the option for server, for listing purposes --->
							<option value="">#server#</option>
						</cfif>
						<option value="#selectValue#" <cfif currentValue EQ selectValue>selected</cfif>>&nbsp;&nbsp;&nbsp;&nbsp;#selectOption#
					</cfloop>
				<cfelse>
					<!--- Loop over the query --->
					<cfloop query="csSiteQry">
						<option value="#SiteID#" <cfif currentValue EQ SiteID>selected</cfif>>#SiteName#
					</cfloop>
				</cfif>
			</select>
		</cfoutput>
	</cfsavecontent>
	#application.ADF.forms.wrapFieldHTML(inputHTML,fieldQuery,attributes)#
</cfoutput>